# https://my.tescomobile.ie/tmi-selfcare-web/rest/usage/1/477


# or https://my.tescomobile.ie/tmi-selfcare-web/rest/usage/1/1000000


class Usage:

    def __init__(self, json_blob):
        self.usages = []
        self.oldest_record = ""
        # self.__process_json(json_blob)

    # def __process_json(self, json_blob):
    #     balance_data = json.loads(json_blob)

    #     self.credit_remaining = round(balance_data["mainBalance"], 2)

    #     for addon in balance_data["addonBalance"]:
    #         self.services.append(ServiceBalance(addon))

    # def filter_balances(self, type):
    #     for bal in self.services:
    #         if bal.type() == type and bal.active():
    #             yield bal
                
    # def data(self):
    #     return self.filter_balances("data")

    # def text(self):
    #     return self.filter_balances("text")

    # def voice(self):
    #     return self.filter_balances("voice")

    # def data_remaining(self):
    #     data_tot = 0
    #     for bal in self.data():
    #         data_tot += bal.remaining_balance()
    #     return int(round(data_tot))




from datetime import datetime

class ServiceBalance:

    def __init__(self, addon_data):
        serviceBundle = addon_data["serviceBundle"]
        self.balance_type = serviceBundle["type"]
        self.unit = serviceBundle["unit"]
        self.is_active = serviceBundle["status"] == "ACTIVE"
        self.remaining_balance = addon_data["balance"]

        if addon_data["expiryDate"] is not None:
            self.balance_expires = datetime.strptime(addon_data["expiryDate"], "%d-%b-%Y %H:%M")
        else:
            self.balance_expires = None

    def days_remaining(self):
        now = datetime.now()
        return int(round(((self.__balance_expires) - now).days))


from datetime import datetime

class UsageRecord:

    def __init__(self):
        self.test = "test"
        # serviceBundle = addon_data["serviceBundle"]
        # self.balance_type = serviceBundle["type"]
        # self.unit = serviceBundle["unit"]
        # self.is_active = serviceBundle["status"] == "ACTIVE"
        # self.remaining_balance = addon_data["balance"]

    #     if addon_data["expiryDate"] is not None:
    #         self.balance_expires = datetime.strptime(addon_data["expiryDate"], "%d-%b-%Y %H:%M")
    #     else:
    #         self.balance_expires = None

    # def days_remaining(self):
    #     now = datetime.now()
    #     return int(round(((self.__balance_expires) - now).days))


import json
from . import ServiceBalance

class Balances:

    def __init__(self, json_blob):
        self.services = []
        self.__process_json(json_blob)

    def __process_json(self, json_blob):
        balance_data = json.loads(json_blob)

        self.credit_remaining = round(balance_data["mainBalance"], 2)

        for addon in balance_data["addonBalance"]:
            self.services.append(ServiceBalance(addon))

    def filter_balances(self, type):
        for bal in self.services:
            if bal.type() == type and bal.active():
                yield bal

    def data(self):
        return self.filter_balances("data")

    def text(self):
        return self.filter_balances("text")

    def voice(self):
        return self.filter_balances("voice")

    def data_remaining(self):
        data_tot = 0
        for bal in self.data():
            data_tot += bal.remaining_balance()
        return int(round(data_tot))





#!/usr/bin/env python
# -*- coding: utf-8 -*-

from .serviceBalance import ServiceBalance
from .balances import Balances
from .usageRecord import UsageRecord
from .usage import Usage
from .tescoSession import TescoSession



#!/usr/bin/env python

from distutils.core import setup

setup(name='pytescomobileirl',
      version='0.1.0',
      description='Python Tesco Mobile (Ireland) API',
      long_description='See project page with usage examples at https://github.com/skhg/pytescomobileirl',
      keywords='tesco mobile phone balance status web ireland api',
      author='Jack Higgins',
      author_email='pypi@jackhiggins.ie',
      url='https://github.com/skhg/pytescomobileirl',
      packages=['pytescomobileirl'],
      install_requires=[
          'requests'
      ],
      tests_require = [
	  	'mock',
	    'nose',
	    ],
      license='MIT',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.6',
      ]
      )


import requests
from . import Balances
from . import Usage

class TescoSession:

    def __init__(self):
        self.__base_url = "https://my.tescomobile.ie/tmi-selfcare-web/"
        self.__login_url = self.__base_url+"j_spring_security_check"
        self.__logout_url = self.__base_url+"j_spring_security_logout"
        self.__balance_url = self.__base_url+"rest/customer/v2/balance"
        self.__usage_url = self.__base_url+"rest/usage/1/"

        self.__session = requests.session()

    def login(self, phone_num, password):
        login_details = {'j_username': phone_num, 'j_password': password}

        try:
            login_result = self.__session.post(self.__login_url, data=login_details)
        except:
            return False

        return login_result.ok

    def logout(self):
        self.__session.get(self.__logout_url)
        self.__session.close()

    def get_balances(self):
        json_balances = self.__session.get(self.__balance_url).content

        return Balances(json_balances)

    def get_usage(self, limit=20):
        json_usage_record = self.__session.get(self.__usage_url+str(limit)).content

        return Usage(json_usage_record)